clear
set more off
set matsize 800
global date "`c(current_date)'"


*************************************************


**************************************************





********************************************************************************
********************************************************************************
*** PREPARE DATASETS
********************************************************************************
********************************************************************************

***Oil price (NEW for MENA weahlth sharing report)
import excel "$data\Oil price\Oil price RWTCa.xls", sheet("use") firstrow clear

save "$dtafiles\Oil price.dta", replace



*** Subsidies, Grants, Social Contributions
import excel "$data\Expense (% of GDP).xls", clear firstrow

reshape long y, i( CountryName CountryCode IndicatorName IndicatorCode ) j(year)

rename y ExpensePercGDP

save "$dtafiles\Expense Percent GDP.dta", replace



*** Government Revenue
import excel "$data\WEOOct2023all.xlsx", clear firstrow

keep if WEOSubjectCode == "GGR_NGDP"

reshape long y, i( WEOCountryCode ISO WEOSubjectCode Country SubjectDescriptor SubjectNotes Units Scale CountrySeriesspecificNotes EstimatesStartAfter ) j(year)

rename y revenue

//transform revenuenm to numerical 
replace revenue="" if revenue=="n/a" 
destring revenue, gen(revenuenm)

//make expenditurenm in share and not in % of gdp: 
generate revenueshare =revenuenm/100

label var revenueshare "General Government Revenue, share of GDP (IMF WEO October 2023)"

save "$dtafiles\General Government Revenue.dta", replace



*** Government Expenditure
import excel "$data\WEOOct2023all.xlsx", clear firstrow

keep if WEOSubjectCode == "GGX_NGDP"

reshape long y, i( WEOCountryCode ISO WEOSubjectCode Country SubjectDescriptor SubjectNotes Units Scale CountrySeriesspecificNotes EstimatesStartAfter ) j(year)

rename y expenditure

//transform revenuenm to numerical 
replace expenditure="" if expenditure=="n/a" 
destring expenditure, gen(expenditurenum)

//make expenditurenm in share and not in % of gdp: 
generate expshare =expenditurenum/100

label var expshare "General government total expenditure, share of GDP (IMF WEO October 2023)"

save "$dtafiles\General Government Total Expenditure.dta", replace



*** Real GDP LCU
import excel "$data\Real GDP LCU.xls", clear sheet("Data") firstrow

reshape long y, i( CountryName CountryCode IndicatorName IndicatorCode ) j(year)

rename y GDP

save "$dtafiles\Real GDP LCU_M.dta", replace



*** GDP Per Capita USD (to order countries according to incoem level)
import excel "$data\GDP per capita (constant 2015 USD).xls", clear sheet("Data") firstrow

reshape long y, i( CountryName CountryCode IndicatorName IndicatorCode ) j(year)

rename y gdppcusd

gen gdppcusd2000x = gdppcusd if year==2000

bysort CountryName : egen gdppcusd2000 = max(gdppcusd2000x)
drop gdppcusd2000x

save "$dtafiles\Real GDPPC USD.dta", replace



*** WEO to WDI key
import excel "$data\WEO to WDI Codes.xlsx", firstrow clear sheet("Final")

save "$dtafiles\WEO to WDI Codes.dta", replace



*** Merge all datasets
use "$dtafiles\General Government Revenue.dta", clear

merge 1:1 ISO year using "$dtafiles\General Government Total Expenditure.dta"
drop _m

merge m:1  ISO using "$dtafiles\WEO to WDI Codes.dta", keepusing("ISO" "CountryCode")
drop _m

*Merge WDI Dataset: Real GDP LCU
merge 1:1 CountryCode year using "$dtafiles\Real GDP LCU_M.dta"
keep if _m==1 | _m==3
drop _m

*Merge WDI Dataset: Real GDP per Capita USD
merge 1:1 CountryCode year using "$dtafiles\Real GDPPC USD.dta"
keep if _m==1 | _m==3
drop _m	

merge 1:1 CountryCode year using "$dtafiles\Expense Percent GDP.dta"
keep if _m==1 | _m==3
drop _m	

merge m:1 year using "$dtafiles\Oil price.dta"  //NEW
keep if _m==1 | _m==3
drop _m	


keep if inrange(year,1999,2022)

tab Country if CountryName==""
drop if CountryName==""


replace Country="Iran" if Country=="Islamic Republic of Iran"



********************************************************************************
********************************************************************************
*** COMPUTE CYCLICAL COMPONENTS (HP filter)
********************************************************************************
********************************************************************************

////////////////////////////////////////////////////////////////////
*Remove if GDP or Revenue not both present: 
drop if   GDP==.  | revenueshare==. | expshare==. 
////////////////////////////////////////////////////////////////////

ren CountryCode wbcode
ren ISO imfcode


*Generate MENA Dummy
generate MENA=.
replace MENA=1 if wbcode=="DZA" | wbcode=="BHR" | wbcode=="DJI" | wbcode=="EGY" | wbcode=="IRN" | wbcode=="IRQ" | wbcode=="JOR" | wbcode=="KWT"  |wbcode=="LBN" | wbcode=="LBY" | wbcode=="MAR" | wbcode=="OMN" | wbcode=="PSE" | wbcode=="QAT" | wbcode=="SAU" | wbcode=="SYR" | wbcode=="TUN" | wbcode=="ARE" | wbcode=="YEM" 


*MENA resource rich
//based on: oil/gas revenue >3 % GDP in 2012-2022
gen MENA_oil = .
replace MENA_oil=1 if wbcode=="SAU" | wbcode=="IRN" | wbcode=="IRQ" | wbcode=="ARE" | wbcode=="KWT" | wbcode=="QAT" | wbcode=="OMN" | wbcode=="YEM" | wbcode=="EGY" | wbcode=="LBY" | wbcode=="DZA"  ///
| wbcode=="BHR" | wbcode=="SYR" //new!


*Generate Egypt Comparators Dummy
gen comparator=.
replace comparator=1 if inlist(Country, "Indonesia", "Jordan", "Morocco", "Peru", "Philippines", "Poland") |  inlist(Country, "Türkiye", "Ukraine", "Vietnam", "Mexico", "Pakistan", "Malaysia", "Sri Lanka", "Tunisia")



*Declara Panel Dataset
encode wbcode, gen (wbcodenm)
tsset wbcodenm year
sort wbcodenm year




*NEW)HP filter for: oil price
*create HP filter with smoothing lambda = 6.25
tsfilter hp oilprice_hp = oilprice, smooth(6.25)
label var oilprice_hp "HP TimeSeries Cyclical Component Filter on Oil Price (USD per Barrel), smoothing Lambda 6.25"



*1)HP filter for: log GDP LCU
gen ln_gdp = ln(GDP)
label var ln_gdp "Log of Real GDP, LCU (WDI)"
label var GDP "Real GDP, LCU (WDI)"
 
*create HP filter with smoothing lambda = 6.25
tsfilter hp gdp_hp = ln_gdp, smooth(6.25)
label var gdp_hp "HP TimeSeries Cyclical Component Filter on Log of Real GDP LCU, smoothing Lambda 6.25"



*2) HP Filter for: log Real Revenue LCU
* Real Revenue LCU = Revenue Share of GDP * Real GDP LCU
gen real_rev = revenueshare*GDP
label var real_rev "Real Revenue LCU (Calculated)"

* Log of Real Revenue LCU
gen log_real_rev = ln(real_rev)
label var log_real_rev "Log of Real Revenue LCU (Calculated)"

* Apply HP Filter with 6.25 smoothing lambda: 
tsfilter hp rev_hp = log_real_rev, smooth(6.25)
label var rev_hp "HP TimeSeries Cyclical Component Filter on Log of Real Revenue LCU, smoothing Lambda 6.25"



*3) HP Filter for: Revenue SHARE
tsfilter hp revshare_hp = revenueshare, smooth(6.25)



*4) HP Filter for: log Real Expenditure LCU
* Real Expenditure LCU = Expenditure Share of GDP * Real GDP LCU
gen real_exp = expshare*GDP
label var real_exp "Real Expenditure LCU (Calculated)"

* Log of Real Expenditure LCU
gen log_realexp = ln(real_exp)
label var log_realexp "Log of Real Expenditure LCU (Calculated)"

* Apply HP Filter with 6.25 smoothing lambda: 
tsfilter hp exp_hp = log_realexp, smooth(6.25)
label var exp_hp "HP TimeSeries Cyclical Component Filter on Log of Real Expenditure LCU, smoothing Lambda 6.25"



*5) HP Filter for: Expenditure SHARE
tsfilter hp expshare_hp = expshare, smooth(6.25)



*6) General government (structural) balance:
gen balance_hp = rev_hp -  exp_hp




sort wbcodenm

save "$dtafiles\DATA_rev.dta", replace




********************************************************************************
********************************************************************************
***NEW: Correlation Analysis for OIL PRICE
********************************************************************************
********************************************************************************

*NEW (MENA wealth sharing report): OIL PRICE

use "$dtafiles\DATA_rev.dta", clear
keep if inrange(year,2000,2022)
egen corrhp_exp_oilprice_00_22 = corr(exp_hp oilprice_hp) , by(wbcodenm)
bysort wbcode: gen count_obs_exp_00_22=_N 
save "$dtafiles\corrhp_exp_oilprice_00_22.dta", replace


use "$dtafiles\DATA_rev.dta", clear
keep if inrange(year,2000,2022)
egen corrhp_expshare_oilprice_00_22 = corr(expshare_hp oilprice_hp) , by(wbcodenm)
bysort wbcode: gen count_obs_expshare_00_22=_N 
save "$dtafiles\corrhp_expshare_oilprice_00_22.dta", replace


merge 1:1 wbcode year using "$dtafiles\corrhp_exp_oilprice_00_22.dta"
keep if _m ==3
drop _m


*collapsing to 1 obs per country
collapse (first)  Country MENA MENA_oil   (max) corrhp_exp_oilprice_00_22 count_obs_exp_00_22     corrhp_expshare_oilprice_00_22 count_obs_expshare_00_22   gdppcusd2000 , by(wbcode)


keep if MENA==1
drop if corrhp_exp_oilprice_00_22 ==. | corrhp_expshare_oilprice_00_22==.  
drop if gdppcusd2000 ==.  //Djibouti


gsort MENA_oil  corrhp_exp_oilprice_00_22  //-gdppcusd2000
export excel "$tabfigs\Correlation Results per Country - MENA_oil (Wealth Sharing report).xlsx", firstrow(variables)  sheet("Sheet1", replace)




