clear
set more off
set matsize 800
global date "`c(current_date)'"


*************************************************
*DEFINE PATHS:

global DRIVE "C:\WBG\github\273final\PACKAGE v4\PACKAGE v4\Figures Stata"  //<--- Adjust!

global data "$DRIVE\Data"
global dtafiles "$DRIVE\Output\dtafiles"
global tabfigs "$DRIVE\Tabfigs"


sysdir set PLUS "${DRIVE}\ado"
set varabbrev on
ssc install egenmore

**************************************************




********************************************************************************
********************************************************************************
*** PREPARE DATASETS
********************************************************************************
********************************************************************************


*** Conflict
import excel "$data\Conflict\death-rate-in-armed-conflicts.xlsx", sheet("death-rate-in-armed-conflicts") firstrow clear

rename Entity country
rename Code CountryCode
rename Year year
rename Deathrate conflict //death rate per 100,000


do country_routine
tab country if dcountry==0
drop if dcountry==0 //East Germany, Taiwan, ..
tab country if dcountry==99
drop if dcountry==99
drop dcountry

rename country CountryName
keep CountryName CountryCode year conflict

sort CountryName year


save "$dtafiles\Conflict.dta", replace




*** GDP pc PPP
import excel "$data\GDPpc\GDPpc.xls", clear firstrow

reshape long y, i( CountryName CountryCode IndicatorName IndicatorCode ) j(year)

rename y gdppc

save "$dtafiles\GDPpc.dta", replace


*** GDP pc growth
import excel "$data\GDPpc growth\GDPpc growth.xls", clear firstrow

reshape long y, i( CountryName CountryCode IndicatorName IndicatorCode ) j(year)

rename y gdppcgrowth

save "$dtafiles\GDPpc growth.dta", replace


*** Population
import excel "$data\Population\population.xls", clear firstrow

reshape long y, i( CountryName CountryCode IndicatorName IndicatorCode ) j(year)

rename y population

save "$dtafiles\population.dta", replace


*** Poverty rate
import excel "$data\Poverty rate\Poverty LMIC.xls", clear firstrow

reshape long y, i( CountryName CountryCode IndicatorName IndicatorCode ) j(year)

rename y pov365

save "$dtafiles\Poverty LMIC.dta", replace


*** Child mortality
import excel "$data\Child mortality\childmortality.xls", clear firstrow

reshape long y, i( CountryName CountryCode IndicatorName IndicatorCode ) j(year)

rename y childmortality

save "$dtafiles\childmortality.dta", replace


*** Gini index
import excel "$data\Gini\Gini.xls", clear firstrow

reshape long y, i( CountryName CountryCode IndicatorName IndicatorCode ) j(year)

rename y gini

save "$dtafiles\Gini.dta", replace


*** HCI
import excel "$data\HCI\HCI.xls", clear firstrow

// values only 2010-2020, with gaps: use 2020 also for 2021
gen y2021 = y2020
 
reshape long y, i( CountryName CountryCode IndicatorName IndicatorCode ) j(year)

rename y HCI

save "$dtafiles\HCI.dta", replace


*** Oil rents (% GDP)
import excel "$data\Oil rents\oil.xls", clear firstrow

reshape long y, i( CountryName CountryCode IndicatorName IndicatorCode ) j(year)

rename y oil

save "$dtafiles\oil.dta", replace


*** Gas rents
import excel "$data\Gas rents\gas.xls", clear firstrow

reshape long y, i( CountryName CountryCode IndicatorName IndicatorCode ) j(year)

rename y gas

save "$dtafiles\gas.dta", replace


*** Natural resource rents
import excel "$data\Natural resource rents\natres.xls", clear firstrow

reshape long y, i( CountryName CountryCode IndicatorName IndicatorCode ) j(year)

rename y natres

save "$dtafiles\natres.dta", replace



*** Inequality measures (WIID)
use "$data\Gini\WIID_28NOV2023x.dta", clear

keep if resource==4 & scale==1 & sharing_unit==1 & reference_unit==1 & areacovr==1 & currency=="US$2017PPP"

do country_routine
tab country if dcountry==0
drop if dcountry==0 //aggregates, Taiwan
tab country if dcountry==99
drop if dcountry==99
drop dcountry

sort country year

duplicates tag  country year ,gen(dup)
tab dup
drop if dup>0 & quality!=1
drop dup

rename gini giniWIID
keep country year giniWIID ge0 ge1 ge2 a025 a050 a075 a1 a2 palma ratio_top20bottom20 bottom40

save "$dtafiles\WIID.dta", replace





*** HDI
import excel "$data\HDI\HDI.xlsx", clear firstrow
// values only for 2022
gen year = 2022
rename HumanDev HDI 
rename Country country

do country_routine
tab country if dcountry==0
drop if dcountry==0 //aggregates
tab country if dcountry==99
drop if dcountry==99
drop dcountry

keep country year HDI

save "$dtafiles\HDI.dta", replace




*** Merge all datasets
use "$dtafiles\GDPpc.dta", clear

merge 1:1 CountryCode year using "$dtafiles\GDPpc growth.dta"
drop _m

merge 1:1 CountryCode year using "$dtafiles\population.dta"
drop _m

merge 1:1 CountryCode year using "$dtafiles\Poverty LMIC.dta"
drop _m

merge 1:1 CountryCode year using "$dtafiles\childmortality.dta"
drop _m

merge 1:1 CountryCode year using "$dtafiles\Gini.dta"
drop _m

merge 1:1 CountryCode year using "$dtafiles\HCI.dta"
drop _m

merge 1:1 CountryCode year using "$dtafiles\oil.dta"
drop _m

merge 1:1 CountryCode year using "$dtafiles\gas.dta"
drop _m

merge 1:1 CountryCode year using "$dtafiles\natres.dta"
drop _m

merge 1:1 CountryCode year using "$dtafiles\Conflict.dta"
tab CountryName if _m==1 & inrange(year,1989,2022) //aggregates
tab CountryName if _m==2  //Kosovo
keep if _m==3 | _m==1
drop _m

drop IndicatorName IndicatorCode
rename  CountryCode wbcode
rename CountryName country

do country_routine
tab country if dcountry==0
drop if dcountry==0 //aggregates
tab country if dcountry==99
drop if dcountry==99
drop dcountry

sort country year

merge 1:1 country year using "$dtafiles\WIID.dta"
drop _m  //  995 obs in WIID

merge 1:1 country year using "$dtafiles\HDI.dta"
drop _m  //  193 countries for 2022 in HDI


format country country_orig %-30s


*Generate MENA Dummy
generate MENA=.
replace MENA=1 if wbcode=="DZA" | wbcode=="BHR" | wbcode=="DJI" | wbcode=="EGY" | wbcode=="IRN" | wbcode=="IRQ"   | wbcode=="JOR" | wbcode=="KWT"  |wbcode=="LBN" | wbcode=="LBY" | wbcode=="MAR" | wbcode=="OMN" | wbcode=="PSE" | wbcode=="QAT" | wbcode=="SAU" | wbcode=="SYR" | wbcode=="TUN" | wbcode=="ARE" | wbcode=="YEM" 
// | wbcode=="ISR"



gen oilgas = oil+gas
sort country year

preserve
keep if inrange(year,2012,2024)
collapse (mean) MENA oil gas oilgas ,by(country)
sort oilgas 
list country oil gas oilgas if MENA==1
restore

//based on: oil/gas revenue >3 % GDP in 2012-2021 (no data for 2022 yet)
gen MENA_oil = .
replace MENA_oil=1 if wbcode=="SAU" | wbcode=="IRN" | wbcode=="IRQ" | wbcode=="ARE" | wbcode=="KWT" | wbcode=="QAT" | wbcode=="OMN" | wbcode=="YEM" | wbcode=="EGY" | wbcode=="LBY" | wbcode=="DZA"  ///
| wbcode=="BHR" | wbcode=="SYR" //new!



tab country if MENA_oil==1  //oil-rich

tab country if MENA==1 & MENA_oil!=1  //NON oil-rich

sort MENA_oil country year
//br country_clean MENA_oil if year==2020 & MENA==1


replace country_clean = "Egypt, Arab Rep." if country_clean=="Egypt"
replace country_clean = "Iran, Islamic Rep." if country_clean=="Iran"
replace country_clean = "Yemen, Rep." if country_clean=="Yemen"

gen lab_MENA     = country_clean if MENA==1
gen lab_MENA_oil = country_clean if MENA_oil==1


*global sample
gen oilgasrich3 = (oilgas>3) if oilgas!=.
replace oilgasrich3=0 if country=="palestine"

//ensure that MENA_oil countries are classified as oil-rich in all years:
replace oilgasrich3 = 1 if MENA_oil==1


gen dconflict = (conflict>0) if conflict!=.



save "$dtafiles\DATA_2012_24_yearly.dta", replace


*work with average values for the period 2010-2024 (for those years with available data)
keep if inrange(year,2010,2024)
collapse (first) wbcode  country_clean  MENA  MENA_oil  lab_MENA  lab_MENA_oil ///
	(mean) gdppc gdppcgrowth population pov365 childmortality gini HCI oil gas oilgas natres HDI conflict ///
	giniWIID ge1 a1 palma ratio_top20bottom20  ,by(country)



drop giniWIID


*complement GDP pc data
//replace gdppc=3275 if country=="syria" //source: 


gen natrich = (natres>10) if natres!=.
gen lab_natrich = country if natrich==1

gen oilgasrich2 = (oilgas>2) if oilgas!=.
gen oilgasrich3 = (oilgas>3) if oilgas!=.
gen oilgasrich5 = (oilgas>5) if oilgas!=.

replace oilgasrich2=0 if country=="palestine"
replace oilgasrich3=0 if country=="palestine"
replace oilgasrich5=0 if country=="palestine"


* SAMPLE 
drop if population <300000 // exclude small island states
drop if oilgasrich2==.  //DPR Korea, Eritrea, Sierra Leone
//==>174 countries




save "$dtafiles\DATA_2012_24.dta", replace




********************************************************************************
*** Analysis: Conflict
********************************************************************************

* MENA
use "$dtafiles\DATA_2012_24_yearly.dta", clear
keep if MENA==1

collapse (mean) oilgas dconflict conflict  ,by(MENA_oil year)

keep if inrange(year,1989,2021) 	
//keep if inrange(year,2000,2021)

sort MENA_oil

********************
*Fig 4.1
********************
graph twoway (tsline dconflict if MENA_oil==1, lcolor(green)) (tsline dconflict if MENA_oil!=1 ,lcolor(blue))  ///
		, graphregion(color(white)) bgcolor(white) ///
		yscale(range(0 0.7)) ///
		ylabel(0(0.2)0.8 , format(%9.1f) angle(horizontal) nogrid )  ///
		xtitle("", height(6)) ytitle("Share of countries with conflict-related deaths", height(6)) ///
		legend(order(1 "Oil-rich" 2 "Non-oil-rich" ) cols(2))
graph export "$tabfigs\Fig_4-1_Dconflict_oilgasrich_MENA.png", replace	


********************
*Fig 4.2
********************
graph twoway (tsline conflict if MENA_oil==1, lcolor(green)) (tsline conflict if MENA_oil!=1 ,lcolor(blue))  ///
		, graphregion(color(white)) bgcolor(white) ///
		yscale(range(0 40)) ///
		ylabel(0(10)40 , format(%9.0f) angle(horizontal) nogrid )  ///
		xtitle("", height(6)) ytitle("Conflict-related deaths (per 100,000 people)", height(6)) ///
		legend(order(1 "Oil-rich" 2 "Non-oil-rich" ) cols(2))
graph export "$tabfigs\Fig_4-2_conflict_oilgasrich_MENA.png", replace	


*prepare Excel source file for figures:
export excel "$tabfigs\Sourcefile_MENA_conflict.xlsx", firstrow(variables)  sheet("MENA", replace)







********************************************************************************
********************************************************************************
*** Analysis: Human Development
********************************************************************************
********************************************************************************

********************
*Fig 1.2 - HCI
********************
use "$dtafiles\DATA_2012_24.dta", clear
graph twoway (scatter HCI gdppc , msymbol(Oh) mcolor(gray)  )  ///
		(fpfit HCI gdppc if oilgasrich2==1 ,lcolor(sienna) ) /// 
		(fpfit HCI gdppc if oilgasrich2==0 ,lcolor(green) lpattern(--))  /// 
		(scatter HCI gdppc if MENA_oil==1, mlab(lab_MENA_oil) mlabcolor(black) mcolor(black) )  ///		
		, graphregion(color(white)) bgcolor(white) ///
		yscale(range(0 1) ) ///
		ylabel(0(0.2)1 , format(%9.1f) angle(horizontal) nogrid )  ///
		xscale(range(0 100000)) ///
		xlabel(0(20000)100000, format(%10.0fc) angle(horizontal) nogrid) ///
		xtitle("GDP per capita (US$)", height(6)) ytitle("Human capital index", height(6)) ///
		legend(order(2 "Trend: Oil-rich" 3 "Trend: Non-oil-rich" ))
graph export "$tabfigs\Fig_1-2_HCI_gdppc.png", replace	



********************
*Fig 1.2 - Poverty
********************
use "$dtafiles\DATA_2012_24.dta", clear
graph twoway (scatter pov365 gdppc , msymbol(Oh) mcolor(gray)  )  ///
		(fpfit pov365 gdppc if oilgasrich2==1 ,lcolor(sienna) ) /// 
		(fpfit pov365 gdppc if oilgasrich2==0 ,lcolor(green) lpattern(--))  /// 
		(scatter pov365 gdppc if MENA_oil==1, mlab(lab_MENA_oil) mlabcolor(black) mcolor(black) )  ///		
		, graphregion(color(white)) bgcolor(white) ///
		yscale(range(0 100)) ///
		ylabel(0(20)100 , format(%9.0f) angle(horizontal) nogrid )  ///
		xscale(range(0 100000)) ///
		xlabel(0(20000)100000, format(%10.0fc) angle(horizontal) nogrid) ///
		xtitle("GDP per capita (US$)", height(6)) ytitle("Poverty rate ($3.65 a day)", height(6)) ///
		legend(order(2 "Trend: Oil-rich" 3 "Trend: Non-oil-rich" ))
graph export "$tabfigs\Fig_1-2_pov365_gdppc.png", replace	



********************
*Fig 1.3 - Child Mortality
********************
use "$dtafiles\DATA_2012_24.dta", clear
graph twoway (scatter childmortality gdppc , msymbol(Oh) mcolor(gray)  )  ///
		(fpfit childmortality gdppc if oilgasrich2==1 ,lcolor(sienna) ) /// 
		(fpfit childmortality gdppc if oilgasrich2==0 ,lcolor(green) lpattern(--))  /// 
		(scatter childmortality gdppc if MENA_oil==1, mlab(lab_MENA_oil) mlabcolor(black) mcolor(black) )  ///		
		, graphregion(color(white)) bgcolor(white) ///
		yscale(range(0 125)) ///
		ylabel(0(25)125 , format(%9.0f) angle(horizontal) nogrid )  ///
		xscale(range(0 100000)) ///
		xlabel(0(20000)100000, format(%10.0fc) angle(horizontal) nogrid) ///
		xtitle("GDP per capita (US$)", height(6)) ytitle("Child mortality", height(6)) ///
		legend(order(2 "Trend: Oil-rich" 3 "Trend: Non-oil-rich" ))
graph export "$tabfigs\Fig_1-3_childmortality_gdppc.png", replace	





********************
*Fig 1.3 - Gini
********************
use "$dtafiles\DATA_2012_24.dta", clear
graph twoway (scatter gini gdppc , msymbol(Oh) mcolor(gray)  )  ///
		(fpfit gini gdppc if oilgasrich2==1 ,lcolor(sienna) ) /// 
		(fpfit gini gdppc if oilgasrich2==0 ,lcolor(green) lpattern(--))  /// 
		(scatter gini gdppc if MENA_oil==1, mlab(lab_MENA_oil) mlabcolor(black) mcolor(black) )  ///		
		, graphregion(color(white)) bgcolor(white) ///
		yscale(range(0 100)) ///
		ylabel(0(20)100 , format(%9.0f) angle(horizontal) nogrid)  ///
		xscale(range(0 100000)) ///
		xlabel(0(20000)100000, format(%10.0fc) angle(horizontal) nogrid) ///
		xtitle("GDP per capita (US$)", height(6)) ytitle("Gini coefficient", height(6)) ///
		legend(order(2 "Trend: Oil-rich" 3 "Trend: Non-oil-rich" ))
graph export "$tabfigs\Fig_1-3_gini_gdppc.png", replace	






********************
*Fig 1.4
********************
use "$dtafiles\DATA_2012_24.dta", clear //actually: 2010-2024

sum gdppc ,det
local med_gdppc = r(p50)
sum HCI ,det
local med_HCI = r(p50)

gen med_gdppc = `med_gdppc'
gen med_HCI	= `med_HCI'

keep if MENA==1

graph twoway (scatter HCI gdppc ,  msymbol(Oh) mcolor(gray) mlabcolor(gray) mlab(lab_MENA) )  ///
	(scatter HCI gdppc if MENA_oil==1, mlab(lab_MENA_oil) mlabcolor(black) mcolor(black) ///		
			xline( `med_gdppc', lcolor(black) lpattern(--))    ///
		yline( `med_HCI', lcolor(black) lpattern(--))  )   ///
		, graphregion(color(white)) bgcolor(white) ///
		yscale(range(0.2 1)) ///
		ylabel(0(0.2)1 , format(%9.1f) angle(horizontal) nogrid)  ///
		xscale(range(0 130000)) ///
		xlabel(0(20000)120000, format(%10.0fc) angle(horizontal) nogrid) ///
		xtitle("GDP per capita (US$)", height(6)) ytitle("Human capital index", height(6)) ///
		legend(order(2 "Oil-rich" 1 "Non-oil-rich" 3 "--- Median (world)") cols(3))
graph export "$tabfigs\Fig_1-4_HCI_gdppc_MENA.png", replace	
//////////////////////////////////////
*Export data for figure to Excel as source files
keep country_clean wbcode MENA MENA_oil /*oilgasrich2*/ gdppc med_gdppc HCI med_HCI
order country_clean wbcode MENA MENA_oil /*oilgasrich2*/ gdppc med_gdppc HCI med_HCI
            
keep if HCI!=. & gdppc!=.
sort country
export excel using "$tabfigs\DATA_Fig1-3.xlsx",  sheet("Data") sheetreplace firstrow(variables)
/////////////////////////////////////


do "Cylicality Dofile - MENA Wealth Sharing Report - replication Fig 2-3.do"

